API Documentation for repoze.workflow
======================================

Interfaces
----------

.. autoclass:: repoze.workflow.statemachine.StateMachine

.. autointerface:: repoze.workflow.interfaces.IStateMachine

Exceptions
----------

.. autoexception:: repoze.workflow.statemachine.StateMachineError
